@@ -1,17 +1,25 @@
 package Graphics::ColorNamesLite::All;
 
-our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-06-09'; # DATE
-our $DIST = 'Graphics-ColorNamesLite-All'; # DIST
-our $VERSION = '0.001'; # VERSION
+use strict;
 
-# note: SVG=CSS, WWW=CSS. GrayScale returns coderef.
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2023-11-30'; # DATE
+our $DIST = 'Graphics-ColorNamesLite-All'; # DIST
+our $VERSION = '0.002'; # VERSION
+
+# note: SVG=CSS, WWW=CSS. GrayScale returns coderef. Pantone are numbers.
 our $NAMES_RGB_TABLE = {
   "aab"                     => "0066ff",
   "aac"                     => "0099ff",
   "abu"                     => 808080,
+  "airyblue"                => "92b6d5",
   "akua"                    => "00ffff",
   "aliceblue"               => "f0f8ff",
+  "almondbuff"              => "d1b894",
+  "almostmauve"             => "eadedb",
+  "amazon"                  => "1c734b",
+  "amberglow"               => "dc793e",
+  "amethystorchid"          => "926aa6",
   "antiquewhite"            => "faebd7",
   "antiquewhite1"           => "ffefdb",
   "antiquewhite2"           => "eedfcc",
@@ -25,11 +33,18 @@ our $NAMES_RGB_TABLE = {
   "aquamarine2"             => "76eec6",
   "aquamarine3"             => "66cdaa",
   "aquamarine4"             => "458b74",
+  "aquasky"                 => "7fcdcd",
+  "arcadia"                 => "00a591",
+  "arcticwolf"              => "e6decf",
   "arterialbloodred"        => 711518,
+  "ash"                     => "a09998",
   "ashgrey"                 => "cbc8b7",
   "asparagusgreen"          => "c2c190",
+  "aspengold"               => "ffd662",
   "auriculapurple"          => 533552,
-  "aurorared"               => "cd6d57",
+  "aurorared"               => "b93a32",
+  "autumnblonde"            => "f2d6b3",
+  "autumnmaple"             => "d2691e",
   "azure"                   => "f0ffff",
   "azure-azure-blue"        => "0066ff",
   "azure-azure-cyan"        => "0099ff",
@@ -42,12 +57,16 @@ our $NAMES_RGB_TABLE = {
   "azureblue"               => "5c6b8f",
   "b"                       => "0000ff",
   "bakerschocolate"         => "5c3317",
+  "balletslipper"           => "f3d6e4",
+  "basil"                   => "829f82",
   "bba"                     => "0033ff",
   "bbv"                     => "3300ff",
   "beige"                   => "f5f5dc",
   "berlinblue"              => "7994b5",
+  "bikingred"               => "77212e",
   "biru"                    => "0000ff",
   "birutua"                 => "000080",
+  "biscaygreen"             => "56c6a9",
   "bisque"                  => "ffe4c4",
   "bisque1"                 => "ffe4c4",
   "bisque2"                 => "eed5b7",
@@ -58,6 +77,7 @@ our $NAMES_RGB_TABLE = {
   "blackishgreen"           => "5d6161",
   "blackishgrey"            => "5b5c61",
   "blanchedalmond"          => "ffebcd",
+  "bloomingdahlia"          => "ec9787",
   "blue"                    => "0000ff",
   "blue-blue-azure"         => "0033ff",
   "blue-blue-violet"        => "3300ff",
@@ -69,14 +89,19 @@ our $NAMES_RGB_TABLE = {
   "blueblueviolet"          => "3300ff",
   "bluegreen"               => "0083ae",
   "bluegrey"                => "b2bbc0",
+  "blueizis"                => "5b5ea6",
+  "bluestone"               => 577284,
+  "blueturquoise"           => "55b4b0",
   "blueviolet"              => "8a2be2",
   "bluishblack"             => "413f44",
   "bluishgreen"             => "a4b6a7",
   "bluishgrey"              => "9c9d9a",
   "bluishlilacpurple"       => "d0d5d3",
   "bluishpurple"            => "8590ae",
+  "bodacious"               => "b76ba3",
   "brass"                   => "b5a642",
   "brightgold"              => "d9d919",
+  "brilliantwhite"          => "edf1ff",
   "broccolibrown"           => "9b856b",
   "bronze"                  => "8c7853",
   "bronzeii"                => "a67d3d",
@@ -85,6 +110,7 @@ our $NAMES_RGB_TABLE = {
   "brown2"                  => "ee3b3b",
   "brown3"                  => "cd3333",
   "brown4"                  => "8b2323",
+  "browngranite"            => 615550,
   "brownishorange"          => "92462f",
   "brownishpurplered"       => "8d746f",
   "brownishred"             => "6e3b31",
@@ -94,7 +120,11 @@ our $NAMES_RGB_TABLE = {
   "burlywood2"              => "eec591",
   "burlywood3"              => "cdaa7d",
   "burlywood4"              => "8b7355",
+  "burntcoral"              => "e9897e",
   "burntsienna"             => "bd6638",
+  "buttercream"             => "efe1ce",
+  "buttercup"               => "fae03c",
+  "butterum"                => "c48f65",
   "c"                       => "00ffff",
   "cadetblue"               => "5f9ea0",
   "cadetblue1"              => "98f5ff",
@@ -102,29 +132,42 @@ our $NAMES_RGB_TABLE = {
   "cadetblue3"              => "7ac5cd",
   "cadetblue4"              => "53868b",
   "campanulapurple"         => "6c6d94",
+  "caramelcafe"             => "8b5a3e",
   "carminered"              => "ce536b",
   "carnationpink"           => "fa7fc1",
   "cca"                     => "00ccff",
   "cct"                     => "00ffcc",
   "celadinegreen"           => "b8bfaf",
+  "cerulean"                => "9bb7d4",
+  "ceruleanblue"            => "98b4d4",
   "cerulian"                => "0071cd",
+  "ceylonyellow"            => "d5ae41",
   "chartreuse"              => "7fff00",
   "chartreuse1"             => "7fff00",
   "chartreuse2"             => "76ee00",
   "chartreuse3"             => "66cd00",
   "chartreuse4"             => "458b00",
+  "cherrytomato"            => "e94b3c",
   "chestnut"                => 954535,
   "chestnutbrown"           => "7a4b3a",
+  "chilioil"                => 944743,
+  "chilipepper"             => "9b2335",
   "chinablue"               => 383867,
+  "chiseledstone"           => "8f8f93",
+  "chive"                   => "4b5335",
   "chocolate"               => "d2691e",
   "chocolate1"              => "ff7f24",
   "chocolate2"              => "ee7621",
   "chocolate3"              => "cd661d",
   "chocolate4"              => "8b4513",
   "chocolatered"            => "4d3635",
+  "cinnamonstic"            => "9c4722",
+  "classicblue"             => "34568b",
   "clovebrown"              => 766051,
   "cobalt"                  => "3d414c",
+  "cocamocha"               => "8c725f",
   "cochinealred"            => "7a4848",
+  "coconutmilk"             => "f0ede5",
   "coolcopper"              => "d98719",
   "copper"                  => "b87333",
   "coral"                   => "ff7f50",
@@ -132,6 +175,7 @@ our $NAMES_RGB_TABLE = {
   "coral2"                  => "ee6a50",
   "coral3"                  => "cd5b45",
   "coral4"                  => "8b3e2f",
+  "coralpink"               => "e8a798",
   "cornflower"              => "6590d8",
   "cornflowerblue"          => "6495ed",
   "cornsilk"                => "fff8dc",
@@ -140,8 +184,10 @@ our $NAMES_RGB_TABLE = {
   "cornsilk3"               => "cdc8b1",
   "cornsilk4"               => "8b8878",
   "creamyellow"             => "f3daa7",
+  "cremedepeche"            => "f5d6c6",
   "crimson"                 => "dc143c",
   "crimsonred"              => "b7757c",
+  "crocuspetal"             => "be9ec9",
   "cyan"                    => "00ffff",
   "cyan-cyan-azure"         => "00ccff",
   "cyan-cyan-teal"          => "00ffcc",
@@ -153,6 +199,8 @@ our $NAMES_RGB_TABLE = {
   "cyancyanteal"            => "00ffcc",
   "dab"                     => "003399",
   "dac"                     => "006699",
+  "daffodil"                => "fdc04e",
+  "dahliamauve"             => "a64f82",
   "dandelion"               => "edd80b",
   "dark azure-blue"         => "003399",
   "dark azure-cyan"         => "006699",
@@ -225,6 +273,7 @@ our $NAMES_RGB_TABLE = {
   "darkblueazure"           => "0033cc",
   "darkblueviolet"          => "3300cc",
   "darkbrown"               => "5c4033",
+  "darkcheddar"             => "e08119",
   "darkcyan"                => "008b8b",
   "darkcyan-azure"          => "0099cc",
   "darkcyan-teal"           => "00cc99",
@@ -377,6 +426,7 @@ our $NAMES_RGB_TABLE = {
   "deepskyblue2"            => "00b2ee",
   "deepskyblue3"            => "009acd",
   "deepskyblue4"            => "00688b",
+  "desertmist"              => "e0b589",
   "dfb"                     => "000099",
   "dfc"                     => "009999",
   "dfg"                     => "009900",
@@ -418,6 +468,7 @@ our $NAMES_RGB_TABLE = {
   "dtc"                     => "009966",
   "dtg"                     => "009933",
   "duckgreen"               => "33431e",
+  "dustycedar"              => "ad5d5d",
   "dustyrose"               => 856363,
   "dutchorange"             => "dfa837",
   "dvb"                     => 330099,
@@ -430,39 +481,57 @@ our $NAMES_RGB_TABLE = {
   "dwy"                     => 666633,
   "dyo"                     => "cc9900",
   "dys"                     => "99cc00",
+  "eclipse"                 => 343148,
+  "eden"                    => "264e36",
+  "emerald"                 => "009b77",
   "emeraldgreen"            => "93b778",
+  "emperador"               => "6c4f3d",
+  "eveningblue"             => "2a293e",
+  "fadeddenim"              => "798ea4",
   "feldspar"                => "d19275",
+  "fiesta"                  => "dd4132",
   "firebrick"               => "b22222",
   "firebrick1"              => "ff3030",
   "firebrick2"              => "ee2c2c",
   "firebrick3"              => "cd2626",
   "firebrick4"              => "8b1a1a",
+  "firedbrick"              => "6a2e2a",
+  "flame"                   => "f2552c",
+  "flamescarlet"            => "cd212a",
   "flaxflowerblue"          => "6f88af",
   "flesh"                   => "f5ccb0",
   "fleshred"                => "e9c49d",
   "floralwhite"             => "fffaf0",
   "forestgreen"             => "228b22",
+  "frenchblue"              => "0072b5",
   "frenchgrey"              => "bebeb3",
+  "fruitdove"               => "ce5b78",
   "fuchsia"                 => "ff00ff",
+  "fuchsiarose"             => "c3447a",
   "fuscia"                  => "ff00ff",
   "g"                       => "00ff00",
   "gainsboro"               => "dcdcdc",
+  "galaxyblue"              => "2a4b7c",
   "gallstoneyellow"         => "a36629",
   "gambogeyellow"           => "e6d058",
   "ggs"                     => "33ff00",
   "ggt"                     => "00ff33",
   "ghostwhite"              => "f8f8ff",
+  "glacierlake"             => "84a2bb",
   "gold"                    => "ffd700",
   "gold1"                   => "ffd700",
   "gold2"                   => "eec900",
   "gold3"                   => "cdad00",
   "gold4"                   => "8b7500",
+  "goldenlime"              => "9c9a40",
   "goldenrod"               => "daa520",
   "goldenrod1"              => "ffc125",
   "goldenrod2"              => "eeb422",
   "goldenrod3"              => "cd9b1d",
   "goldenrod4"              => "8b6914",
+  "gossamerpink"            => "f9c5c2",
   "grannysmithapple"        => "5cbf64",
+  "grapecompote"            => "6b5876",
   "grassgreen"              => "7d8c55",
   "gray"                    => 808080,
   "gray0"                   => "000000",
@@ -573,14 +642,18 @@ our $NAMES_RGB_TABLE = {
   "green2"                  => "00ee00",
   "green3"                  => "00cd00",
   "green4"                  => "008b00",
+  "greenash"                => "a0daa9",
   "greencopper"             => 856363,
+  "greenflash"              => "79c753",
   "greengreenspring"        => "33ff00",
   "greengreenteal"          => "00ff33",
   "greenishblack"           => 454445,
   "greenishblue"            => "719ba2",
   "greenishgrey"            => "8a8d84",
   "greenishwhite"           => "f2ebcd",
+  "greensheen"              => "d9ce52",
   "greenyellow"             => "adff2f",
+  "grenadine"               => "dc4c46",
   "grey"                    => 808080,
   "grey0"                   => "000000",
   "grey1"                   => "030303",
@@ -686,7 +759,11 @@ our $NAMES_RGB_TABLE = {
   "greyishblack"            => 555152,
   "greyishblue"             => "8aa1a6",
   "greyishwhite"            => "e2ddc6",
+  "guacamole"               => "797b3a",
   "hairbrown"               => "8b7859",
+  "harborblue"              => "16737f",
+  "harbormist"              => "b4b7ba",
+  "hazelnut"                => "cfb095",
   "hijau"                   => "008000",
   "hitam"                   => "000000",
   "honeydew"                => "f0fff0",
@@ -694,6 +771,7 @@ our $NAMES_RGB_TABLE = {
   "honeydew2"               => "e0eee0",
   "honeydew3"               => "c1cdc1",
   "honeydew4"               => "838b83",
+  "honeysucle"              => "d65076",
   "honeyyellow"             => "a77d35",
   "hotpink"                 => "ff69b4",
   "hotpink1"                => "ff6eb4",
@@ -702,6 +780,8 @@ our $NAMES_RGB_TABLE = {
   "hotpink4"                => "8b3a62",
   "huntergreen"             => "8e2323",
   "hyacinthred"             => "a75536",
+  "icedcoffee"              => "b18f6a",
+  "illuminating"            => "f5df4d",
   "imperialpurple"          => "584c77",
   "indianred"               => "cd5c5c",
   "indianred1"              => "ff6a6a",
@@ -711,12 +791,17 @@ our $NAMES_RGB_TABLE = {
   "indigo"                  => "4b0082",
   "indigoblue"              => "4f638d",
   "inkblack"                => 252024,
+  "inkwell"                 => 363945,
+  "innuendo"                => "c43f66",
+  "islandparadise"          => "95dee3",
   "ivory"                   => "fffff0",
   "ivory1"                  => "fffff0",
   "ivory2"                  => "eeeee0",
   "ivory3"                  => "cdcdc1",
   "ivory4"                  => "8b8b83",
+  "jesterred"               => "9e1030",
   "k"                       => "000000",
+  "kale"                    => "5a7247",
   "kapur"                   => "00ff00",
   "khaki"                   => "f0e68c",
   "khaki1"                  => "fff68f",
@@ -728,6 +813,9 @@ our $NAMES_RGB_TABLE = {
   "lab"                     => "6699ff",
   "lac"                     => "66ccff",
   "lakered"                 => "b74a70",
+  "lapisblue"               => "004b8d",
+  "lark"                    => "b89b72",
+  "lavafalls"               => "9f383a",
   "lavender"                => "e6e6fa",
   "lavenderblush"           => "fff0f5",
   "lavenderblush1"          => "fff0f5",
@@ -975,12 +1063,19 @@ our $NAMES_RGB_TABLE = {
   "lightyellow4"            => "8b8b7a",
   "lightyelloworange"       => "ffcc33",
   "lightyellowspring"       => "ccff33",
+  "lilacgrey"               => "9896a4",
   "lime"                    => "00ff00",
   "limegreen"               => "32cd32",
+  "limelight"               => "f1ea7f",
+  "limepunc"                => "bfd641",
+  "limpetshell"             => "98ddde",
   "linen"                   => "faf0e6",
+  "littleboyblue"           => "6f9fd8",
   "liverbrown"              => "513e32",
+  "livingcoral"             => "ff6f61",
   "lmp"                     => "ff33cc",
   "lmv"                     => "cc33ff",
+  "lodenfrost"              => "758e77",
   "lor"                     => "ff9966",
   "loy"                     => "ffcc66",
   "lpm"                     => "ff66cc",
@@ -991,6 +1086,7 @@ our $NAMES_RGB_TABLE = {
   "lsy"                     => "ccff66",
   "ltc"                     => "66ffcc",
   "ltg"                     => "66ff99",
+  "lushmeadow"              => "006e51",
   "lvb"                     => "9966ff",
   "lvm"                     => "cc66ff",
   "lwb"                     => "9999cc",
@@ -1014,14 +1110,21 @@ our $NAMES_RGB_TABLE = {
   "magenta4"                => "8b008b",
   "magentamagentapink"      => "ff00cc",
   "magentamagentaviolet"    => "cc00ff",
+  "magentapurple"           => "6c244c",
   "mahogany"                => "ba4f35",
   "mandarianorange"         => "8e2323",
+  "mangomojito"             => "d69c2f",
+  "marigold"                => "fdac53",
+  "marina"                  => "4f84c4",
   "maroon"                  => 800000,
   "maroon1"                 => "ff34b3",
   "maroon2"                 => "ee30a7",
   "maroon3"                 => "cd2990",
   "maroon4"                 => "8b1c62",
+  "marsala"                 => 955251,
+  "martiniolive"            => "766f57",
   "mauvelous"               => "d0687e",
+  "meadowlark"              => "ecdb54",
   "medium azure-blue"       => "3366cc",
   "medium azure-cyan"       => "3399cc",
   "medium faded blue"       => "3333cc",
@@ -1101,6 +1204,7 @@ our $NAMES_RGB_TABLE = {
   "mediumweakred"           => 996666,
   "mediumweakyellow"        => 999966,
   "mediumwood"              => "a68064",
+  "meerkat"                 => "a9754f",
   "melon"                   => "f6857d",
   "merah"                   => "ff0000",
   "merahmarun"              => 800000,
@@ -1110,7 +1214,10 @@ our $NAMES_RGB_TABLE = {
   "mfm"                     => "cc33cc",
   "mfr"                     => "cc3333",
   "mfy"                     => "cccc33",
+  "midnight"                => "315d78",
   "midnightblue"            => 191970,
+  "mimosa"                  => "efc050",
+  "mint"                    => "00a170",
   "mintcream"               => "f5fffa",
   "mistyrose"               => "ffe4e1",
   "mistyrose1"              => "ffe4e1",
@@ -1121,6 +1228,7 @@ our $NAMES_RGB_TABLE = {
   "mmv"                     => "cc00ff",
   "moccasin"                => "ffe4b5",
   "mor"                     => "cc6633",
+  "mosaicblue"              => "00758f",
   "mountaingreen"           => "b2b599",
   "moy"                     => "cc9933",
   "mpm"                     => "cc3399",
@@ -1143,11 +1251,18 @@ our $NAMES_RGB_TABLE = {
   "navajowhite3"            => "cdb38b",
   "navajowhite4"            => "8b795e",
   "navy"                    => "000080",
+  "navyblazer"              => "282d3c",
   "navyblue"                => "23238e",
+  "navypeony"               => "223a5e",
+  "nebulasblue"             => "3f69aa",
   "neonblue"                => "4d4dff",
   "neonpink"                => "ff6ec7",
+  "neutralgray"             => "898e8c",
   "newmidnightblue"         => "00009c",
   "newtan"                  => "ebc79e",
+  "niagara"                 => "578ca9",
+  "northerndroplet"         => "bdc0bf",
+  "nosegay"                 => "f0c0d8",
   "obscure dull azure"      => "003366",
   "obscure dull blue"       => "000066",
   "obscure dull cyan"       => "006666",
@@ -1222,11 +1337,13 @@ our $NAMES_RGB_TABLE = {
   "orangecolouredwhite"     => "f3e9ca",
   "orangeorangered"         => "ff6600",
   "orangeorangeyellow"      => "ff9900",
+  "orangepeel"              => "fa7a35",
   "orangered"               => "ff4500",
   "orangered1"              => "ff4500",
   "orangered2"              => "ee4000",
   "orangered3"              => "cd3700",
   "orangered4"              => "8b2500",
+  "orangetiger"             => "f96714",
   "orchid"                  => "da70d6",
   "orchid1"                 => "ff83fa",
   "orchid2"                 => "ee7ae9",
@@ -1259,6 +1376,7 @@ our $NAMES_RGB_TABLE = {
   "pale weak red"           => "ffcccc",
   "pale weak yellow"        => "ffffcc",
   "paleblackishpurple"      => "4a475c",
+  "paledogwood"             => "edcdc2",
   "paledullazure"           => "99ccff",
   "paledullblue"            => "9999ff",
   "paledullcyan"            => "99ffff",
@@ -1294,6 +1412,7 @@ our $NAMES_RGB_TABLE = {
   "paleweakmagenta"         => "ffccff",
   "paleweakred"             => "ffcccc",
   "paleweakyellow"          => "ffffcc",
+  "paloma"                  => "9f9c99",
   "pansypurple"             => "39334a",
   "papayawhip"              => "ffefd5",
   "pda"                     => "99ccff",
@@ -1310,13 +1429,18 @@ our $NAMES_RGB_TABLE = {
   "pdy"                     => "ffff99",
   "peach"                   => "f5bc89",
   "peachblossomred"         => "eecfbf",
+  "peachecho"               => "f7786b",
+  "peachnougat"             => "e6af91",
+  "peachpink"               => "fa9a85",
   "peachpuff"               => "ffdab9",
   "peachpuff1"              => "ffdab9",
   "peachpuff2"              => "eecbad",
   "peachpuff3"              => "cdaf95",
   "peachpuff4"              => "8b7765",
   "pearlgrey"               => "b7b5ac",
+  "pepperstem"              => "8d9440",
   "perak"                   => "c0c0c0",
+  "perfectlypale"           => "d5ccc1",
   "peru"                    => "cd853f",
   "pg"                      => "cccccc",
   "pink"                    => "ffc0cb",
@@ -1326,8 +1450,11 @@ our $NAMES_RGB_TABLE = {
   "pink2"                   => "eea9b8",
   "pink3"                   => "cd919e",
   "pink4"                   => "8b636c",
+  "pinklavender"            => "dbb1cd",
+  "pinkpeacock"             => "c62168",
   "pinkpinkmagenta"         => "ff0099",
   "pinkpinkred"             => "ff0066",
+  "pinkyarrow"              => "ce3175",
   "pistachiogreen"          => "8e9849",
   "pitchorbrownishblack"    => 423937,
   "plum"                    => "dda0dd",
@@ -1336,10 +1463,15 @@ our $NAMES_RGB_TABLE = {
   "plum3"                   => "cd96cd",
   "plum4"                   => "8b668b",
   "plumpurple"              => 463759,
+  "poinciana"               => "c94235",
+  "polarnight"              => 434550,
+  "poppyseed"               => "66686c",
+  "pottersclay"             => "9e4624",
   "powderblue"              => "b0e0e6",
   "ppm"                     => "ff0099",
   "ppr"                     => "ff0066",
-  "primroseyellow"          => "ebdd99",
+  "primroseyellow"          => "f6d155",
+  "princessblue"            => "00539c",
   "prussianblue"            => "1c1949",
   "purple"                  => 800080,
   "purple1"                 => "9b30ff",
@@ -1357,7 +1489,11 @@ our $NAMES_RGB_TABLE = {
   "pwr"                     => "ffcccc",
   "pwy"                     => "ffffcc",
   "quartz"                  => "d9d9f3",
+  "quetzalgreen"            => "006e6d",
+  "quietgray"               => "bcbcbe",
   "r"                       => "ff0000",
+  "radiandorchid"           => "b565a7",
+  "raspberrysorbet"         => "d2386c",
   "rawsienna"               => "9f6a3b",
   "rebeccapurple"           => 663399,
   "red"                     => "ff0000",
@@ -1372,11 +1508,17 @@ our $NAMES_RGB_TABLE = {
   "reddishwhite"            => "f2e7cf",
   "redlilacpurple"          => "bfbac0",
   "redorange"               => "f1612a",
+  "redpear"                 => "7f4145",
   "redredorange"            => "ff3300",
   "redredpink"              => "ff0033",
   "redviolet"               => "b32f79",
   "richblue"                => "5959ab",
+  "riverside"               => "4c6a92",
+  "rockyroad"               => "5a3e36",
+  "rosequartz"              => "f7cac9",
   "rosered"                 => "eedac3",
+  "rosetan"                 => "d19c97",
+  "roseviolet"              => "c15391",
   "rosybrown"               => "bc8f8f",
   "rosybrown1"              => "ffc1c1",
   "rosybrown2"              => "eeb4b4",
@@ -1389,16 +1531,25 @@ our $NAMES_RGB_TABLE = {
   "royalblue4"              => "27408b",
   "rro"                     => "ff3300",
   "rrp"                     => "ff0033",
+  "russetorange"            => "e47a2e",
+  "rust"                    => "b55a30",
   "rustyred"                => 822007,
   "saddlebrown"             => "8b4513",
+  "saffron"                 => "ffa500",
   "saffronyellow"           => "d09b2c",
+  "sailorblue"              => "2e4a62",
   "salmon"                  => "fa8072",
   "salmon1"                 => "ff8c69",
   "salmon2"                 => "ee8262",
   "salmon3"                 => "cd7054",
   "salmon4"                 => "8b4c39",
+  "samba"                   => "a2242f",
+  "samoansun"               => "f5cc72",
+  "sanddollar"              => "dfcfbe",
+  "sandstone"               => "c48a69",
   "sandybrown"              => "f4a460",
   "sapgreen"                => "7c8635",
+  "sargassosea"             => 485167,
   "scarlet"                 => "ed3825",
   "scarletred"              => "b63e36",
   "scotchblue"              => "281f3f",
@@ -1414,6 +1565,9 @@ our $NAMES_RGB_TABLE = {
   "seashell4"               => "8b8682",
   "semisweetchocolate"      => "6b4226",
   "sepia"                   => "6c4f3c",
+  "serenity"                => "91a8d0",
+  "shadedspruce"            => "005960",
+  "sharkskin"               => 838487,
   "sienna"                  => "a0522d",
   "sienna1"                 => "ff8247",
   "sienna2"                 => "ee7942",
@@ -1428,6 +1582,7 @@ our $NAMES_RGB_TABLE = {
   "skyblue2"                => "7ec0ee",
   "skyblue3"                => "6ca6cd",
   "skyblue4"                => "4a708b",
+  "skydiver"                => "1e609e",
   "slateblue"               => "6a5acd",
   "slateblue1"              => "836fff",
   "slateblue2"              => "7a67ee",
@@ -1440,15 +1595,19 @@ our $NAMES_RGB_TABLE = {
   "slategray4"              => "6c7b8b",
   "slategrey"               => 708090,
   "smokegrey"               => "bfbbb0",
+  "snorkelblue"             => "034f84",
   "snow"                    => "fffafa",
   "snow1"                   => "fffafa",
   "snow2"                   => "eee9e9",
   "snow3"                   => "cdc9c9",
   "snow4"                   => "8b8989",
-  "snowwhite"               => "f1e9cd",
+  "snowwhite"               => "f2f0eb",
+  "soybean"                 => "d2c29d",
+  "spicymustard"            => "d8ae47",
   "spicypink"               => "ff1cae",
   "spring-spring-green"     => "66ff00",
   "spring-spring-yellow"    => "99ff00",
+  "springcrocus"            => "bc70a4",
   "springgreen"             => "00ff7f",
   "springgreen1"            => "00ff7f",
   "springgreen2"            => "00ee76",
@@ -1456,6 +1615,7 @@ our $NAMES_RGB_TABLE = {
   "springgreen4"            => "008b45",
   "springspringgreen"       => "66ff00",
   "springspringyellow"      => "99ff00",
+  "spunsugar"               => "b8deec",
   "ssg"                     => "66ff00",
   "ssy"                     => "99ff00",
   "steelblue"               => "4682b4",
@@ -1464,41 +1624,58 @@ our $NAMES_RGB_TABLE = {
   "steelblue3"              => "4f94cd",
   "steelblue4"              => "36648b",
   "strawyellow"             => "f0d696",
+  "sugaralmond"             => 935529,
   "sulphuryellow"           => "ccc050",
   "summersky"               => "38b0de",
+  "sunlight"                => "edd59e",
+  "sweetcorn"               => "f0ead6",
+  "sweetlilac"              => "e8b5ce",
   "tan"                     => "d2b48c",
   "tan1"                    => "ffa54f",
   "tan2"                    => "ee9a49",
   "tan3"                    => "cd853f",
   "tan4"                    => "8b5a2b",
+  "tangerinetango"          => "dd4124",
+  "tawnyport"               => "672e3b",
   "teal"                    => "008080",
   "teal-teal-cyan"          => "00ff99",
   "teal-teal-green"         => "00ff66",
   "tealtealcyan"            => "00ff99",
   "tealtealgreen"           => "00ff66",
+  "terrariummoss"           => 616247,
   "thistle"                 => "d8bfd8",
   "thistle1"                => "ffe1ff",
   "thistle2"                => "eed2ee",
   "thistle3"                => "cdb5cd",
   "thistle4"                => "8b7b8b",
+  "tigerlily"               => "e15d44",
   "tilered"                 => "c76b4a",
   "timberwolf"              => "adb0aa",
+  "toffee"                  => 755139,
+  "tofu"                    => "eae6da",
   "tomato"                  => "ff6347",
   "tomato1"                 => "ff6347",
   "tomato2"                 => "ee5c42",
   "tomato3"                 => "cd4f39",
   "tomato4"                 => "8b3626",
+  "truered"                 => "bc243c",
   "ttc"                     => "00ff99",
   "ttg"                     => "00ff66",
   "tumbleweed"              => "b98a64",
+  "turmeric"                => "fe840e",
   "turquoise"               => "40e0d0",
   "turquoise1"              => "00f5ff",
   "turquoise2"              => "00e5ee",
   "turquoise3"              => "00c5cd",
   "turquoise4"              => "00868b",
+  "ultimategray"            => "96999b",
   "ultramarineblue"         => "657abb",
+  "ultramarinegreen"        => "006b54",
+  "ultraviolet"             => "6b5b95",
   "umberbrown"              => 613936,
   "ungu"                    => 800080,
+  "valiantpoppy"            => "bd3d3a",
+  "vanillacustard"          => "f3e0be",
   "veinousbloodred"         => "3f3033",
   "velvetblack"             => "241f20",
   "verdigrisgreen"          => "61ac86",
@@ -1506,6 +1683,7 @@ our $NAMES_RGB_TABLE = {
   "vermilionred"            => "b5493a",
   "verydarkbrown"           => "5c4033",
   "verylightgrey"           => "cdcdcd",
+  "veryperi"                => "696aad",
   "violet"                  => "ee82ee",
   "violet-violet-blue"      => "6600ff",
   "violet-violet-magenta"   => "9900ff",
@@ -1520,6 +1698,9 @@ our $NAMES_RGB_TABLE = {
   "vvb"                     => "6600ff",
   "vvm"                     => "9900ff",
   "w"                       => "ffffff",
+  "warmsand"                => "c0ab8e",
+  "warmtaupe"               => "af9483",
+  "waterspout"              => "93dbe0",
   "waxyellow"               => "ab9649",
   "webgray"                 => 808080,
   "webgreen"                => "008000",
@@ -1533,6 +1714,7 @@ our $NAMES_RGB_TABLE = {
   "wheat4"                  => "8b7e66",
   "white"                   => "ffffff",
   "whitesmoke"              => "f5f5f5",
+  "willow"                  => "9a8b4f",
   "wineyellow"              => "d7c485",
   "wistera"                 => "b681cf",
   "woodbrown"               => "c39e6d",
@@ -1577,7 +1759,7 @@ Graphics::ColorNamesLite::All - Lots of color names and equivalent RGB values (l
 
 =head1 VERSION
 
-This document describes version 0.001 of Graphics::ColorNamesLite::All (from Perl distribution Graphics-ColorNamesLite-All), released on 2020-06-09.
+This document describes version 0.002 of Graphics::ColorNamesLite::All (from Perl distribution Graphics-ColorNamesLite-All), released on 2023-11-30.
 
 =head1 DESCRIPTION
 
@@ -1591,14 +1773,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/Graphics-C
 
 Source repository is at L<https://github.com/perlancar/perl-Graphics-ColorNamesLite-All>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Graphics-ColorNamesLite-All>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 SEE ALSO
 
 C<Graphics::ColorNames::*>
@@ -1607,11 +1781,37 @@ C<Graphics::ColorNames::*>
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by perlancar@cpan.org.
+This software is copyright (c) 2023 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Graphics-ColorNamesLite-All>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
